==> maven-dependency-plugin_2.4.orig.tar.xz: maven-dependency-plugin-2.4/src/main/java/org/apache/maven/plugin/dependency/AnalyzeMojo.java <==
package org.apache.maven.plugin.dependency;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Analyzes the dependencies of this project and determines which are: used and declared; used and undeclared; unused
 * and declared. This goal is intended to be used standalone, thus it always executes the <code>test-compile</code>
 * phase - use the <code>dependency:analyze-only</code> goal instead when participating in the build lifecycle.
 * 
 * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
 * @version $Id: AnalyzeMojo.java 728546 2008-12-21 22:56:51Z bentmann $
 * @since 2.0-alpha-3
 * @see AnalyzeOnlyMojo
 * 
 * @goal analyze
 * @requiresDependencyResolution test
 * @execute phase="test-compile"
 */
public class AnalyzeMojo
    extends AbstractAnalyzeMojo
{
    // subclassed to provide plexus annotations
}

==> maven-dependency-plugin_2.7.orig.tar.xz: maven-dependency-plugin-2.7/src/main/java/org/apache/maven/plugin/dependency/AnalyzeMojo.java <==
package org.apache.maven.plugin.dependency;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.plugins.annotations.Execute;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.ResolutionScope;

/**
 * Analyzes the dependencies of this project and determines which are: used and declared; used and undeclared; unused
 * and declared. This goal is intended to be used standalone, thus it always executes the <code>test-compile</code>
 * phase - use the <code>dependency:analyze-only</code> goal instead when participating in the build lifecycle.
 * 
 * <p>By default, <a href="http://maven.apache.org/shared/maven-dependency-analyzer/">maven-dependency-analyzer</a> is
 * used to perform the analysis, with limitations due to the fact that it works at bytecode level, but any
 * analyzer can be plugged in through <code>analyzer</code> parameter.</p>
 *
 * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
 * @version $Id: AnalyzeMojo.java 1400739 2012-10-21 23:05:22Z hboutemy $
 * @see AnalyzeOnlyMojo
 * @since 2.0-alpha-3
 */
@Mojo( name = "analyze", requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true )
@Execute( phase = LifecyclePhase.TEST_COMPILE )
public class AnalyzeMojo
    extends AbstractAnalyzeMojo
{
    // subclassed to provide annotations
}
